# Generated by Django 2.2.6 on 2019-10-22 01:22

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("edc_auth", "0009_userprofile_alternate_email")]

    operations = [
        migrations.AlterField(
            model_name="userprofile",
            name="alternate_email",
            field=models.EmailField(
                blank=True,
                max_length=254,
                null=True,
                verbose_name="Alternate email address",
            ),
        )
    ]
