# Generated by Django 3.2.13 on 2022-09-06 23:02

import uuid

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_pharmacy", "0012_auto_20220907_0157"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalrxrefill",
            name="refill_identifier",
            field=models.CharField(default=uuid.uuid4, editable=False, max_length=36),
        ),
        migrations.AlterField(
            model_name="historicalrxrefill",
            name="refill_start_datetime",
            field=models.DateTimeField(
                help_text="Starting date for this refill",
                verbose_name="Refill start date/time",
            ),
        ),
        migrations.AlterField(
            model_name="rxrefill",
            name="refill_identifier",
            field=models.CharField(default=uuid.uuid4, editable=False, max_length=36),
        ),
        migrations.AlterField(
            model_name="rxrefill",
            name="refill_start_datetime",
            field=models.DateTimeField(
                help_text="Starting date for this refill",
                verbose_name="Refill start date/time",
            ),
        ),
    ]
