COMPLETED_FOLLOWUP = "completed_followup"
CONSENT_WITHDRAWAL = "consent_withdrawal"
END_OF_STUDY_ACTION = "submit_end_of_study"
INVALID_ENROLMENT = "invalid_enrolment"
LATE_EXCLUSION = "late_exclusion"
OTHER_RX_DISCONTINUATION = "other_treatment_discontinuation"
WITHDRAWAL = "withdrawal"
