export_codenames = [
    "edc_export.display_export_admin_action",
    "edc_export.add_datarequest",
    "edc_export.add_datarequesthistory",
    "edc_export.add_exportreceipt",
    "edc_export.add_filehistory",
    "edc_export.add_objecthistory",
    "edc_export.add_plan",
    "edc_export.add_uploadexportreceiptfile",
    "edc_export.change_datarequest",
    "edc_export.change_datarequesthistory",
    "edc_export.change_exportreceipt",
    "edc_export.change_filehistory",
    "edc_export.change_objecthistory",
    "edc_export.change_plan",
    "edc_export.change_uploadexportreceiptfile",
    "edc_export.delete_datarequest",
    "edc_export.delete_datarequesthistory",
    "edc_export.delete_exportreceipt",
    "edc_export.delete_filehistory",
    "edc_export.delete_objecthistory",
    "edc_export.delete_plan",
    "edc_export.delete_uploadexportreceiptfile",
    "edc_export.view_datarequest",
    "edc_export.view_datarequesthistory",
    "edc_export.view_exportreceipt",
    "edc_export.view_filehistory",
    "edc_export.view_historicaldatarequest",
    "edc_export.view_historicalexportreceipt",
    "edc_export.view_historicalfilehistory",
    "edc_export.view_historicalobjecthistory",
    "edc_export.view_historicalplan",
    "edc_export.view_objecthistory",
    "edc_export.view_plan",
    "edc_export.view_uploadexportreceiptfile",
    "edc_export.export_subjectschedulehistory",
    "edc_export.export_visitschedule",
    "edc_export.view_export_dashboard",
]
