{% extends edc_lab_listboard_template %}

{% block results_header %}
    {% include 'edc_lab_dashboard/listboard/result/results_header.html' %}
{% endblock results_header %}

{% block results_body %}
    {% include 'edc_lab_dashboard/listboard/result/results_body.html' %}
{% endblock results_body %}
