# Generated by Django 5.2.3 on 2025-06-27 17:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0073_alter_stockout_options"),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="StockOut",
            new_name="StockAvailability",
        ),
        migrations.RenameIndex(
            model_name="stockavailability",
            new_name="edc_pharmac_subject_3f9cb2_idx",
            old_name="edc_pharmac_subject_63b1ce_idx",
        ),
    ]
