# Generated by Django 4.0.4 on 2022-06-02 01:53

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_appointment", "0029_appointment_ignore_window_period_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="appointment",
            name="appt_status",
            field=models.CharField(
                choices=[
                    ("new", "Not started"),
                    ("in_progress", "In Progress"),
                    ("incomplete", "Incomplete"),
                    ("done", "Done"),
                    ("cancelled", "Cancelled"),
                ],
                db_index=True,
                default="new",
                help_text="If the visit has already begun, only 'in progress', 'incomplete' or 'done' are valid options. Only unscheduled appointments may be cancelled.",
                max_length=25,
                verbose_name="Status",
            ),
        ),
        migrations.AlterField(
            model_name="appointment",
            name="appt_timing",
            field=models.CharField(
                choices=[
                    ("ontime", "On time (within window period)"),
                    ("missed", "Missed"),
                ],
                default="ontime",
                help_text="If late, you may be required to complete a Protocol Deviation / Violation form. Refer to the protocol/SOP for the definition of scheduled appointment window periods.",
                max_length=25,
                verbose_name="Timing",
            ),
        ),
        migrations.AlterField(
            model_name="historicalappointment",
            name="appt_status",
            field=models.CharField(
                choices=[
                    ("new", "Not started"),
                    ("in_progress", "In Progress"),
                    ("incomplete", "Incomplete"),
                    ("done", "Done"),
                    ("cancelled", "Cancelled"),
                ],
                db_index=True,
                default="new",
                help_text="If the visit has already begun, only 'in progress', 'incomplete' or 'done' are valid options. Only unscheduled appointments may be cancelled.",
                max_length=25,
                verbose_name="Status",
            ),
        ),
        migrations.AlterField(
            model_name="historicalappointment",
            name="appt_timing",
            field=models.CharField(
                choices=[
                    ("ontime", "On time (within window period)"),
                    ("missed", "Missed"),
                ],
                default="ontime",
                help_text="If late, you may be required to complete a Protocol Deviation / Violation form. Refer to the protocol/SOP for the definition of scheduled appointment window periods.",
                max_length=25,
                verbose_name="Timing",
            ),
        ),
    ]
