# Generated by Django 3.2.13 on 2022-07-14 18:36

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_offstudy", "0010_auto_20220704_1841"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectoffstudy",
            name="offstudy_reason",
            field=models.CharField(
                choices=[
                    ("lost", "Lost to follow-up"),
                    ("completed protocol", "Completed protocol"),
                    ("consent_withdrawn", "Consent withdrawn"),
                    ("dead", "Deceased"),
                ],
                max_length=125,
                verbose_name="Please code the primary reason participant taken off-study",
            ),
        ),
        migrations.AlterField(
            model_name="subjectoffstudy",
            name="offstudy_reason",
            field=models.CharField(
                choices=[
                    ("lost", "Lost to follow-up"),
                    ("completed protocol", "Completed protocol"),
                    ("consent_withdrawn", "Consent withdrawn"),
                    ("dead", "Deceased"),
                ],
                max_length=125,
                verbose_name="Please code the primary reason participant taken off-study",
            ),
        ),
    ]
