# Generated by Django 3.2.13 on 2022-07-08 05:05

import uuid

import _socket
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import simple_history.models
from django.conf import settings
from django.db import migrations, models

import edc_pharmacy.models.medication


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("sites", "0002_alter_domain_unique"),
        ("edc_pharmacy", "0008_auto_20220706_2324"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="HistoricalMedicationProduct",
            new_name="HistoricalProduct",
        ),
        migrations.RenameModel(
            old_name="MedicationProduct",
            new_name="Product",
        ),
        migrations.RenameModel(
            old_name="HistoricalMedicationStock",
            new_name="HistoricalStock",
        ),
        migrations.RenameModel(
            old_name="HistoricalMedicationStockCreateLabels",
            new_name="HistoricalStockCreateLabels",
        ),
        migrations.RenameModel(
            old_name="HistoricalMedicationStockReceiving",
            new_name="HistoricalStockReceiving",
        ),
        migrations.RenameModel(
            old_name="MedicationStock",
            new_name="Stock",
        ),
        migrations.RenameModel(
            old_name="MedicationStockCreateLabels",
            new_name="StockCreateLabels",
        ),
        migrations.RenameModel(
            old_name="MedicationStockReceiving",
            new_name="StockReceiving",
        ),
    ]
