{% extends edc_base_template %}
{% load static %}

{% block main %}

{{ block.super }}

  <div class="col-sm-4">&nbsp;
  </div>

  <div class="col-sm-4">
    <div class="panel panel-default">
      <div class="panel-heading">Subject Review</div>
      <div class="list-group">
        <a id="subject_review_group_home" href="{% url 'home_url' %}" class="list-group-item"><i class="fas fa-reply fa-1x fa-fw" aria-hidden="true"></i> Home</a>
      </div>
    </div>
  </div>

  <div class="col-sm-4">&nbsp;
  </div>
{% endblock main %}
