CANCELLED = "cancelled"
CSV = "CSV"
DELETE = "D"
EXPORTED = "exported"
INSERT = "I"
UPDATE = "U"
STATA_10 = 114
STATA_13 = 117
STATA_14 = 118
STATA_15 = 119

EXPORT = "EXPORT"
EXPORT_PII = "EXPORT_PII"
DATA_EXPORTER_ROLE = "data_exporter"
