# Generated by Django 5.1 on 2024-08-14 17:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_qareports", "0012_alter_qareportnote_note"),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="QaReportNote",
            new_name="Note",
        ),
        migrations.RemoveConstraint(
            model_name="note",
            name="edc_qareports_qareportnote_report_model_subj_uniq",
        ),
        migrations.RenameIndex(
            model_name="note",
            new_name="edc_qarepor_modifie_90fe6c_idx",
            old_name="edc_qarepor_modifie_5f102f_idx",
        ),
        migrations.RenameIndex(
            model_name="note",
            new_name="edc_qarepor_user_mo_d0d80a_idx",
            old_name="edc_qarepor_user_mo_6166bf_idx",
        ),
        migrations.AddConstraint(
            model_name="note",
            constraint=models.UniqueConstraint(
                fields=("report_model", "subject_identifier"),
                name="edc_qareports_note_report_model_subj_uniq",
            ),
        ),
    ]
