# Generated by Django 5.2.6 on 2025-09-17 16:53

import edc_model_fields.fields.other_charfield
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_visit_tracking", "0008_alter_historicalsubjectvisit_revision_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="comments",
            field=models.TextField(
                blank=True,
                default="",
                max_length=250,
                verbose_name="Comment if any additional pertinent information about the participant",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="document_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this document",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="info_source_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                default="",
                max_length=35,
                verbose_name='If "Other" source of information, specify',
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="reason_missed",
            field=models.CharField(
                blank=True,
                choices=[
                    ("timepoint", "Missed timepoint"),
                    ("OTHER", "Other"),
                    ("N/A", "Not applicable"),
                ],
                default="",
                max_length=35,
                verbose_name="If 'missed', provide the reason for the missed visit",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="reason_missed_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                default="",
                max_length=25,
                verbose_name='If the reason for the missed visit is "other", specify',
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="study_status",
            field=models.CharField(
                default="",
                max_length=50,
                verbose_name="What is the participant's current study status",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="survival_status",
            field=models.CharField(
                choices=[
                    ("alive", "Alive"),
                    ("dead", "Deceased"),
                    ("unknown", "Unknown"),
                    ("N/A", "Not applicable (if missed)"),
                ],
                default="alive",
                help_text="If YES, submit Death report",
                max_length=10,
                verbose_name="Participant's survival status",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="visit_code",
            field=models.CharField(default="", editable=False, max_length=25),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="comment",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="Please provide further details, if any",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="contact_attempts_explained",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="If contact not made and less than 3 attempts, please explain",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="comments",
            field=models.TextField(
                blank=True,
                default="",
                max_length=250,
                verbose_name="Comment if any additional pertinent information about the participant",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="document_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this document",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="info_source_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                default="",
                max_length=35,
                verbose_name='If "Other" source of information, specify',
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="reason_missed",
            field=models.CharField(
                blank=True,
                choices=[
                    ("timepoint", "Missed timepoint"),
                    ("OTHER", "Other"),
                    ("N/A", "Not applicable"),
                ],
                default="",
                max_length=35,
                verbose_name="If 'missed', provide the reason for the missed visit",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="reason_missed_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                default="",
                max_length=25,
                verbose_name='If the reason for the missed visit is "other", specify',
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="study_status",
            field=models.CharField(
                default="",
                max_length=50,
                verbose_name="What is the participant's current study status",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="survival_status",
            field=models.CharField(
                choices=[
                    ("alive", "Alive"),
                    ("dead", "Deceased"),
                    ("unknown", "Unknown"),
                    ("N/A", "Not applicable (if missed)"),
                ],
                default="alive",
                help_text="If YES, submit Death report",
                max_length=10,
                verbose_name="Participant's survival status",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="visit_code",
            field=models.CharField(default="", editable=False, max_length=25),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissed",
            name="comment",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="Please provide further details, if any",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissed",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissed",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissed",
            name="contact_attempts_explained",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="If contact not made and less than 3 attempts, please explain",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissed",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissed",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissed",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissed",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissedreasons",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissedreasons",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissedreasons",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="visitreasons",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="visitreasons",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="visitreasons",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
    ]
