{% load crispy_forms_tags %}

<!-- Modal -->
<div id="packAliquotsModal" class="modal fade" role="dialog">

  <div class="modal-dialog">

    <!-- Modal content-->
    <div class="modal-content">
      <div class="modal-header ">
        <button type="button" class="close" data-dismiss="modal">&times;</button>
        <h4 class="modal-title">
            <span class="text text-primary">
                Pack Aliquots
            </span>
        </h4>
      </div>

      <div class="modal-body">

        <div class="panel-group">
            <div class="panel-heading">
            </div>
          <div class="panel panel-default">

            {% crispy pack_aliquots_form %}

          </div>
        </div>


      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-default" data-dismiss="modal">Cancel</button>
      </div>

    </div>
  </div>
</div>
