# Generated by Django 3.0.4 on 2020-05-12 21:34

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_lab", "0020_auto_20191024_1000"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="aliquot",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Aliquot",
            },
        ),
        migrations.AlterModelOptions(
            name="box",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-box_datetime",),
                "verbose_name": "Box",
                "verbose_name_plural": "Boxes",
            },
        ),
        migrations.AlterModelOptions(
            name="boxitem",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("position",),
                "verbose_name": "Box Item",
            },
        ),
        migrations.AlterModelOptions(
            name="boxtype",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("name",),
                "verbose_name": "Box Type",
            },
        ),
        migrations.AlterModelOptions(
            name="consignee",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("name",),
                "verbose_name": "Consignee",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalaliquot",
            options={
                "get_latest_by": "history_date",
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Aliquot",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalbox",
            options={
                "get_latest_by": "history_date",
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Box",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalboxitem",
            options={
                "get_latest_by": "history_date",
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Box Item",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalconsignee",
            options={
                "get_latest_by": "history_date",
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Consignee",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalmanifest",
            options={
                "get_latest_by": "history_date",
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Manifest",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalorder",
            options={
                "get_latest_by": "history_date",
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Order",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalresult",
            options={
                "get_latest_by": "history_date",
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Result",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalresultitem",
            options={
                "get_latest_by": "history_date",
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Result Item",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalshipper",
            options={
                "get_latest_by": "history_date",
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Shipper",
            },
        ),
        migrations.AlterModelOptions(
            name="manifest",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-manifest_identifier",),
                "verbose_name": "Manifest",
            },
        ),
        migrations.AlterModelOptions(
            name="manifestitem",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("created",),
                "verbose_name": "Manifest Item",
            },
        ),
        migrations.AlterModelOptions(
            name="order",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Order",
            },
        ),
        migrations.AlterModelOptions(
            name="panel",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("lab_profile_name", "name"),
                "verbose_name": "Panel",
            },
        ),
        migrations.AlterModelOptions(
            name="result",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Result",
            },
        ),
        migrations.AlterModelOptions(
            name="resultitem",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Result Item",
            },
        ),
        migrations.AlterModelOptions(
            name="shipper",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("name",),
                "verbose_name": "Shipper",
            },
        ),
    ]
