{% load i18n %}

{% trans "To find a death report, search on the subject's study identifier, death report reference number, or AE reference number" %}<BR> {% trans "To download the printable report, click on the PDF button" %} <i class='fas fa-file-pdf fa-fw'></i> {%  trans "left of the subject's identifier." %}
