<a id="print_requisition_popover"
class="btn btn-default" tabindex="0" href="javascript://" data-toggle="popover" data-placement="auto" data-html="true" title="<i class='fas fa-download fa-lg' aria-hidden='true'></i> Download requisition report"
data-content="<p class='h6'>Instructions</p><ol><li class='text text-default'>Select the requisitions to include in your report.</li><li class='text text-default'>Click on a service provider below.</li><li class='text text-default'>Check your browser downloads for the PDF report.</li></ol><p class='h6'>Service Providers</p><div class='list-group'>{% for consignee in consignees %}<button type='submit' id='submit_print_requisition' name='submit_print_requisition' form='form_requisition_print_actions' value='{{ consignee.pk }}' class='list-group-item list-group-item-info' title='select and download'><span class='text text-default'>{{ consignee.name }}</span></button>{% endfor %}<a role='button' href='{% url 'edc_lab_admin:edc_lab_consignee_add' %}' class='list-group-item list-group-item-default' title='add'><span class='text text-default small'><i class='fas fa-plus fa-fw'></i> Add service provider not listed</span></a></div><p><a title='close' class='btn btn-sm btn-primary pull-right'><i class='fas fa-times fa-fw' aria-hidden='true'></i></a><br></p>">
  <span class="text text-default" title="Download requisitions as PDF report"><i class="fas fa-file-pdf fa-fw"></i><i class="fas fa-download fa-fw"></i></span>
</a>
