# Generated by Django 5.2.6 on 2025-09-18 00:24

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_export", "0022_alter_datarequest_description_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="datarequesthistory",
            name="archive_filename",
            field=models.CharField(default="", max_length=200),
        ),
        migrations.AlterField(
            model_name="datarequesthistory",
            name="emailed_to",
            field=models.EmailField(default="", max_length=254),
        ),
        migrations.AlterField(
            model_name="datarequesthistory",
            name="exported_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
    ]
