# Generated by Django 4.2.11 on 2024-08-14 15:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_qareports", "0011_auto_20240813_0219"),
    ]

    operations = [
        migrations.AlterField(
            model_name="qareportnote",
            name="note",
            field=models.TextField(blank=True, null=True),
        ),
    ]
