{% if rule_generated == YES %}
	<span style="color:green"><i class="fas fa-check-circle fa-fw"></i></span>
{% else %}
	<span style="color:red"><i class="fas fa-times-circle fa-fw"></i></span>
{% endif %}
