# Generated by Django 2.1.2 on 2018-11-11 21:36

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("edc_notification", "0001_initial")]

    operations = [
        migrations.AlterField(
            model_name="notification",
            name="name",
            field=models.CharField(max_length=255, unique=True),
        )
    ]
