# Generated by Django 4.2.7 on 2023-12-04 02:32

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_export", "0017_alter_datarequest_options_and_more"),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="objecthistory",
            name="edc_export__modifie_36e5ad_idx",
        ),
        migrations.RemoveIndex(
            model_name="plan",
            name="edc_export__modifie_db36ec_idx",
        ),
        migrations.AddIndex(
            model_name="objecthistory",
            index=models.Index(
                fields=["modified", "created"], name="edc_export__modifie_808a80_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="plan",
            index=models.Index(
                fields=["modified", "created"], name="edc_export__modifie_25ba96_idx"
            ),
        ),
    ]
