# Generated by Django 2.0 on 2017-12-30 13:41

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [("edc_lab", "0010_auto_20171127_1541")]

    operations = [migrations.DeleteModel(name="IdentifierHistory")]
