# Generated by Django 4.2.7 on 2023-12-04 22:19

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "edc_facility",
            "0010_remove_healthfacility_edc_facilit_modifie_dcf8ac_idx_and_more",
        ),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="healthfacilitytypes",
            name="edc_facilit_name_78007a_idx",
        ),
    ]
