# -*- coding: utf-8 -*-
# Generated by Django 1.10.3 on 2016-11-27 22:26
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):
    dependencies = [("edc_appointment", "0002_auto_20161126_1156")]

    operations = [
        migrations.AlterModelOptions(name="appointment", options={}),
        migrations.RemoveField(model_name="historicalappointment", name="consent_version"),
        migrations.AlterField(
            model_name="appointment",
            name="created",
            field=models.DateTimeField(default=django.utils.timezone.now, editable=False),
        ),
        migrations.AlterField(
            model_name="appointment",
            name="modified",
            field=models.DateTimeField(default=django.utils.timezone.now, editable=False),
        ),
        migrations.AlterField(
            model_name="historicalappointment",
            name="created",
            field=models.DateTimeField(default=django.utils.timezone.now, editable=False),
        ),
        migrations.AlterField(
            model_name="historicalappointment",
            name="modified",
            field=models.DateTimeField(default=django.utils.timezone.now, editable=False),
        ),
        migrations.AlterUniqueTogether(name="appointment", unique_together=set([])),
        migrations.RemoveField(model_name="appointment", name="consent_version"),
    ]
