# Generated by Django 4.2.7 on 2023-12-03 00:22

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_facility", "0008_alter_healthfacility_device_created_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="healthfacility",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Facility",
                "verbose_name_plural": "Health Facilities",
            },
        ),
        migrations.AlterModelOptions(
            name="healthfacilitytypes",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Facility Type",
                "verbose_name_plural": "Health Facility Types",
            },
        ),
        migrations.AlterModelOptions(
            name="holiday",
            options={"verbose_name": "Holiday", "verbose_name_plural": "Holidays"},
        ),
        migrations.RemoveIndex(
            model_name="healthfacilitytypes",
            name="edc_facilit_id_05cd80_idx",
        ),
        migrations.AddField(
            model_name="healthfacility",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="healthfacility",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealthfacility",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealthfacility",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="healthfacilitytypes",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="healthfacilitytypes",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="healthfacilitytypes",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AddIndex(
            model_name="healthfacility",
            index=models.Index(
                fields=["-modified", "-created"], name="edc_facilit_modifie_dcf8ac_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healthfacility",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_facilit_user_mo_c7241a_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthfacilitytypes",
            index=models.Index(fields=["name"], name="edc_facilit_name_78007a_idx"),
        ),
        migrations.AddIndex(
            model_name="healthfacilitytypes",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="edc_facilit_display_56fc12_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="holiday",
            index=models.Index(
                fields=["name", "country", "local_date"],
                name="edc_facilit_name_acd5e1_idx",
            ),
        ),
    ]
