ALREADY_REPORTED = "Already reported"
INVALID_REFERENCE = "invalid_reference"
MILD = "mild"
MODERATE = "moderate"
PRESENT_AT_BASELINE = "present_at_baseline"
SEVERE = "severe"
SEVERITY_INCREASED_FROM_G3 = "increase_from_g3"
LLN = "LLN"
ULN = "ULN"
HIGH_VALUE = "9999999999.9"
