{% load tz %}
{% load edc_dashboard_extras %}
{% load static %}


<!--  begin columns  -->
<td>Some data</td>
<td>Some data</td>
<td nowrap>Some data</td>
<td nowrap>Some data</td>
<td nowrap>Some data</td>
<td nowrap>Some data</td>
<!--  end columns  -->
