# Generated by Django 5.2.6 on 2025-09-18 00:24

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_locator",
            "0040_alter_historicalsubjectlocator_action_identifier_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectlocator",
            name="report_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="subjectlocator",
            name="report_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
    ]
