# Generated by Django 4.1 on 2022-08-21 18:54

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_offstudy", "0011_auto_20220714_2136"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalsubjectoffstudy",
            old_name="offstudy_reason_other",
            new_name="other_offstudy_reason",
        ),
        migrations.RenameField(
            model_name="subjectoffstudy",
            old_name="offstudy_reason_other",
            new_name="other_offstudy_reason",
        ),
        migrations.AddField(
            model_name="historicalsubjectoffstudy",
            name="comment",
            field=models.TextField(
                blank=True,
                max_length=500,
                null=True,
                verbose_name="Please provide further details if possible",
            ),
        ),
        migrations.AddField(
            model_name="subjectoffstudy",
            name="comment",
            field=models.TextField(
                blank=True,
                max_length=500,
                null=True,
                verbose_name="Please provide further details if possible",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectoffstudy",
            name="offstudy_reason",
            field=models.CharField(
                choices=[
                    ("lost", "Lost to follow-up"),
                    ("completed protocol", "Completed protocol"),
                    ("consent_withdrawn", "Consent withdrawn"),
                    ("dead", "Deceased"),
                    ("OTHER", "Other, please specify ..."),
                ],
                max_length=125,
                verbose_name="Please code the primary reason participant taken off-study",
            ),
        ),
        migrations.AlterField(
            model_name="subjectoffstudy",
            name="offstudy_reason",
            field=models.CharField(
                choices=[
                    ("lost", "Lost to follow-up"),
                    ("completed protocol", "Completed protocol"),
                    ("consent_withdrawn", "Consent withdrawn"),
                    ("dead", "Deceased"),
                    ("OTHER", "Other, please specify ..."),
                ],
                max_length=125,
                verbose_name="Please code the primary reason participant taken off-study",
            ),
        ),
    ]
