# Generated by Django 5.1.2 on 2024-11-09 22:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pylabels", "0006_delete_drawing"),
    ]

    operations = [
        migrations.AlterField(
            model_name="labelconfiguration",
            name="name",
            field=models.CharField(
                help_text="Name of configuration registered with site_label_config.",
                max_length=50,
                unique=True,
            ),
        ),
    ]
