# Generated by Django 4.2.7 on 2023-12-04 22:19

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "edc_adverse_event",
            "0013_alter_aeactionclassification_device_created_and_more",
        ),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="aeactionclassification",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.AlterModelOptions(
            name="aeclassification",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.AlterModelOptions(
            name="causeofdeath",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.AlterModelOptions(
            name="edcpermissions",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Edc Permissions",
                "verbose_name_plural": "Edc Permissions",
            },
        ),
        migrations.AlterModelOptions(
            name="saereason",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.RemoveIndex(
            model_name="aeactionclassification",
            name="edc_adverse_id_5fd6ee_idx",
        ),
        migrations.RemoveIndex(
            model_name="aeclassification",
            name="edc_adverse_id_6431b6_idx",
        ),
        migrations.RemoveIndex(
            model_name="causeofdeath",
            name="edc_adverse_id_ca88f1_idx",
        ),
        migrations.RemoveIndex(
            model_name="saereason",
            name="edc_adverse_id_dc0e62_idx",
        ),
        migrations.AddField(
            model_name="aeactionclassification",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="aeactionclassification",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="aeclassification",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="aeclassification",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="causeofdeath",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="causeofdeath",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="edcpermissions",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="edcpermissions",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="saereason",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="saereason",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="aeactionclassification",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="aeactionclassification",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="aeactionclassification",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="aeclassification",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="aeclassification",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="aeclassification",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="causeofdeath",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="causeofdeath",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="causeofdeath",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="saereason",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="saereason",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="saereason",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AddIndex(
            model_name="aeactionclassification",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="edc_adverse_display_9f6c78_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="aeactionclassification",
            index=models.Index(
                fields=["modified", "created"], name="edc_adverse_modifie_2d407c_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="aeactionclassification",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_adverse_user_mo_b0d69e_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="aeclassification",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="edc_adverse_display_c2c113_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="aeclassification",
            index=models.Index(
                fields=["modified", "created"], name="edc_adverse_modifie_970ccb_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="aeclassification",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_adverse_user_mo_969781_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="causeofdeath",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="edc_adverse_display_4c7e3b_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="causeofdeath",
            index=models.Index(
                fields=["modified", "created"], name="edc_adverse_modifie_835e5b_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="causeofdeath",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_adverse_user_mo_e41e6f_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="edcpermissions",
            index=models.Index(
                fields=["modified", "created"], name="edc_adverse_modifie_69a2bc_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="edcpermissions",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_adverse_user_mo_7f4957_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="saereason",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="edc_adverse_display_2a23e9_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="saereason",
            index=models.Index(
                fields=["modified", "created"], name="edc_adverse_modifie_439471_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="saereason",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_adverse_user_mo_09db8b_idx",
            ),
        ),
    ]
