# Generated by Django 3.2.13 on 2022-07-04 15:41

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_appointment", "0030_alter_appointment_appt_status_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="historicalappointment",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical appointment",
                "verbose_name_plural": "historical appointments",
            },
        ),
        migrations.AlterField(
            model_name="historicalappointment",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
    ]
