# Generated by Django 4.2.3 on 2023-08-02 23:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_refusal", "0006_alter_subjectrefusal_managers"),
    ]

    operations = [
        migrations.AddField(
            model_name="refusalreasons",
            name="extra_value",
            field=models.CharField(max_length=250, null=True),
        ),
    ]
