# Generated by Django 5.2.3 on 2025-06-29 21:11

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0074_rename_stockout_stockavailability_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalstockrequestitem",
            name="in_stock",
        ),
        migrations.RemoveField(
            model_name="historicalstockrequestitem",
            name="received",
        ),
        migrations.RemoveField(
            model_name="historicalstockrequestitem",
            name="received_datetime",
        ),
        migrations.RemoveField(
            model_name="stockrequestitem",
            name="in_stock",
        ),
        migrations.RemoveField(
            model_name="stockrequestitem",
            name="received",
        ),
        migrations.RemoveField(
            model_name="stockrequestitem",
            name="received_datetime",
        ),
    ]
