# Generated by Django 4.2.11 on 2024-06-18 02:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_qareports", "0003_alter_qareportnote_options_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="qareportnote",
            name="status",
            field=models.CharField(
                choices=[("New", "New"), ("feedback", "Feedback")],
                default="New",
                max_length=25,
            ),
        ),
    ]
