# Generated by Django 4.1.2 on 2023-01-24 15:51

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_appointment", "0036_auto_20230124_1822"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="appointment",
            name="appt_type_old",
        ),
        migrations.RemoveField(
            model_name="historicalappointment",
            name="appt_type_old",
        ),
    ]
