# Generated by Django 3.2.6 on 2021-09-09 23:34

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_navbar", "0002_auto_20210423_1451"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="navbar",
            options={"verbose_name": "Navbar"},
        ),
    ]
