# Generated by Django 4.2.9 on 2024-01-30 05:44

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_auth", "0032_userprofile_is_multisite_viewer"),
    ]

    operations = [
        migrations.AlterField(
            model_name="userprofile",
            name="is_multisite_viewer",
            field=models.BooleanField(
                default=False,
                help_text="Designates if this user may view data from sites other than the current.",
                verbose_name="Multisite viewer",
            ),
        ),
    ]
