# Generated by Django 6.0 on 2025-03-27 22:41

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0068_stockout"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalstoragebin",
            name="capacity",
            field=models.PositiveIntegerField(
                default=0, validators=[django.core.validators.MinValueValidator(0)]
            ),
        ),
        migrations.AlterField(
            model_name="historicalstoragebin",
            name="name",
            field=models.CharField(
                blank=True,
                db_index=True,
                help_text="May be left blank or set to any unique name.",
                max_length=10,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="storagebin",
            name="capacity",
            field=models.PositiveIntegerField(
                default=0, validators=[django.core.validators.MinValueValidator(0)]
            ),
        ),
        migrations.AlterField(
            model_name="storagebin",
            name="name",
            field=models.CharField(
                blank=True,
                help_text="May be left blank or set to any unique name.",
                max_length=10,
                null=True,
                unique=True,
            ),
        ),
    ]
