# Generated by Django 3.2.13 on 2022-09-06 23:07

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_pharmacy", "0013_auto_20220907_0202"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalrxrefill",
            name="refill_end_datetime",
            field=models.DateTimeField(
                help_text="Ending date for this refill",
                null=True,
                verbose_name="Refill end date/time",
            ),
        ),
        migrations.AddField(
            model_name="rxrefill",
            name="refill_end_datetime",
            field=models.DateTimeField(
                help_text="Ending date for this refill",
                null=True,
                verbose_name="Refill end date/time",
            ),
        ),
    ]
