# Generated by Django 5.2.6 on 2025-09-17 16:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_protocol_incident",
            "0023_alter_historicalprotocoldeviationviolation_revision_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="actionsrequired",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="actionsrequired",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="actionsrequired",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="action_identifier",
            field=models.CharField(
                blank=True, db_index=True, default="", max_length=50
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="corrective_action",
            field=models.TextField(
                blank=True, default="", verbose_name="Corrective action taken"
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="preventative_action",
            field=models.TextField(
                blank=True, default="", verbose_name="Preventative action taken"
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="safety_impact_details",
            field=models.TextField(
                blank=True, default="", verbose_name='If "Yes", provide details'
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="short_description",
            field=models.CharField(
                default="",
                help_text='Max 35 characters. Note: If this occurrence is a "violation" there is additional space below for a more detailed description',
                max_length=35,
                verbose_name="Provide a short description of this occurrence",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="study_outcomes_impact_details",
            field=models.TextField(
                blank=True, default="", verbose_name='If "Yes", provide details'
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="violation_description",
            field=models.TextField(
                blank=True,
                default="",
                help_text="Describe in full. Explain how the violation happened, what occurred, etc.",
                verbose_name="Describe the violation",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="violation_other",
            field=models.CharField(
                blank=True,
                default="",
                max_length=75,
                verbose_name="If other, please specify",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="violation_reason",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="Explain the reason why the violation occurred",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="action_identifier",
            field=models.CharField(
                blank=True, db_index=True, default="", max_length=50
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="corrective_action",
            field=models.TextField(
                blank=True, default="", verbose_name="Corrective action taken"
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="incident_description",
            field=models.TextField(
                default="",
                help_text="Describe in full. Explain how the incident happened, what occurred, etc.",
                verbose_name="Describe the incident",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="incident_other",
            field=models.CharField(
                blank=True,
                default="",
                max_length=75,
                verbose_name="If other, please specify",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="incident_reason",
            field=models.TextField(
                default="", verbose_name="Explain the reason why the incident occurred"
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="preventative_action",
            field=models.TextField(
                blank=True, default="", verbose_name="Preventative action taken"
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="reasons_withdrawn",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="safety_impact_details",
            field=models.TextField(
                blank=True, default="", verbose_name='If "Yes", provide details'
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="short_description",
            field=models.CharField(
                default="",
                help_text="Max 35 characters. Note: there is additional space below for a more detailed description",
                max_length=35,
                verbose_name="Provide a short description of this incident",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="study_outcomes_impact_details",
            field=models.TextField(
                blank=True, default="", verbose_name='If "Yes", provide details'
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="action_identifier",
            field=models.CharField(blank=True, default="", max_length=50, unique=True),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="corrective_action",
            field=models.TextField(
                blank=True, default="", verbose_name="Corrective action taken"
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="preventative_action",
            field=models.TextField(
                blank=True, default="", verbose_name="Preventative action taken"
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="safety_impact_details",
            field=models.TextField(
                blank=True, default="", verbose_name='If "Yes", provide details'
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="short_description",
            field=models.CharField(
                default="",
                help_text='Max 35 characters. Note: If this occurrence is a "violation" there is additional space below for a more detailed description',
                max_length=35,
                verbose_name="Provide a short description of this occurrence",
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="study_outcomes_impact_details",
            field=models.TextField(
                blank=True, default="", verbose_name='If "Yes", provide details'
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="violation_description",
            field=models.TextField(
                blank=True,
                default="",
                help_text="Describe in full. Explain how the violation happened, what occurred, etc.",
                verbose_name="Describe the violation",
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="violation_other",
            field=models.CharField(
                blank=True,
                default="",
                max_length=75,
                verbose_name="If other, please specify",
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="violation_reason",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="Explain the reason why the violation occurred",
            ),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="action_identifier",
            field=models.CharField(blank=True, default="", max_length=50, unique=True),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="corrective_action",
            field=models.TextField(
                blank=True, default="", verbose_name="Corrective action taken"
            ),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="incident_description",
            field=models.TextField(
                default="",
                help_text="Describe in full. Explain how the incident happened, what occurred, etc.",
                verbose_name="Describe the incident",
            ),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="incident_other",
            field=models.CharField(
                blank=True,
                default="",
                max_length=75,
                verbose_name="If other, please specify",
            ),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="incident_reason",
            field=models.TextField(
                default="", verbose_name="Explain the reason why the incident occurred"
            ),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="preventative_action",
            field=models.TextField(
                blank=True, default="", verbose_name="Preventative action taken"
            ),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="reasons_withdrawn",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="safety_impact_details",
            field=models.TextField(
                blank=True, default="", verbose_name='If "Yes", provide details'
            ),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="short_description",
            field=models.CharField(
                default="",
                help_text="Max 35 characters. Note: there is additional space below for a more detailed description",
                max_length=35,
                verbose_name="Provide a short description of this incident",
            ),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="study_outcomes_impact_details",
            field=models.TextField(
                blank=True, default="", verbose_name='If "Yes", provide details'
            ),
        ),
        migrations.AlterField(
            model_name="protocolincidents",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="protocolincidents",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="protocolincidents",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="protocolviolations",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="protocolviolations",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="protocolviolations",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
    ]
