# Generated by Django 3.2.11 on 2022-03-04 01:07

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_pharmacy", "0001_initial"),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name="medication",
            unique_together={("name", "display_name")},
        ),
    ]
