from edc_navbar import NavbarItem

dm_navbar_item = NavbarItem(
    name="data_manager_home",
    title="Data Management",
    label="DM",
    codename="edc_data_manager.nav_data_manager_section",
    url_name="edc_data_manager:home_url",
)
