# Generated by Django 5.2.3 on 2025-07-08 12:21

import uuid

import _socket
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import simple_history.models
from django.conf import settings
from django.db import migrations, models

import edc_pharmacy.models.stock.confirmation_at_site_item
import edc_sites.managers


class Migration(migrations.Migration):
    dependencies = [
        ("edc_pharmacy", "0083_auto_20250707_1820"),
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.RenameModel(
            old_name="HistoricalStockTransferConfirmationItem",
            new_name="HistoricalConfirmationAtSiteItem",
        ),
        migrations.RenameModel(
            old_name="StockTransferConfirmationItem",
            new_name="ConfirmationAtSiteItem",
        ),
        migrations.RenameModel(
            old_name="HistoricalStockTransferConfirmation",
            new_name="HistoricalConfirmationAtSite",
        ),
        migrations.RenameModel(
            old_name="StockTransferConfirmation",
            new_name="ConfirmationAtSite",
        ),
    ]
