# Generated by Django 5.1.2 on 2024-11-22 13:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_pharmacy",
            "0051_alter_historicalstocktransferconfirmationitem_options_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="formulation",
            name="imp",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="formulation",
            name="imp_description",
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
        migrations.AddField(
            model_name="historicalformulation",
            name="imp",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="historicalformulation",
            name="imp_description",
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
    ]
