# Generated by Django 4.2.7 on 2023-12-05 19:50

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_data_manager", "0033_datadictionary_locale_created_and_more"),
        ("edc_form_runners", "0002_alter_issue_options_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="Issue",
            fields=[],
            options={
                "verbose_name": "Form validation issue",
                "verbose_name_plural": "Form validation issues",
                "proxy": True,
                "indexes": [],
                "constraints": [],
            },
            bases=("edc_form_runners.issue",),
        ),
    ]
