MEAN_95CI = "mean_95ci"
MEAN_RANGE = "mean_range"
MEAN_SD = "mean_sd"
MEDIAN_IQR = "median_iqr"
MEDIAN_RANGE = "median_range"
N_MEAN = "n_mean"
N_ONLY = "n_only"
N_RANGE = "n_range"
N_WITH_COL_PROP = "n_with_col_prop"
N_WITH_ROW_PROP: str = "n_with_row_prop"

COUNT_COLUMN = "count"
TITLE_COLUMN = "title"

STATISTICS = [
    MEAN_95CI,
    MEAN_RANGE,
    MEAN_SD,
    MEDIAN_IQR,
    MEDIAN_RANGE,
    N_MEAN,
    N_ONLY,
    N_RANGE,
    N_WITH_COL_PROP,
    N_WITH_ROW_PROP,
]
