# Generated by Django 5.2.1 on 2025-06-04 20:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_reportable", "0004_alter_referencerangecollection_grade3_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalnormaldata",
            name="auto_created",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="normaldata",
            name="auto_created",
            field=models.BooleanField(default=False),
        ),
    ]
