{% load i18n %}
<div>
  <a style="white-space: nowrap;background-color:#0b58a2" class="button" title="{{ title |default:"Go to subject's dashboard"}}" href="{{ url }}" {{ disabled|default:'' }} >{{ label|default:"Dashboard" }}</a>
</div>
