{% load i18n admin_urls %}
<div class="submit-row">
  {% if show_save %}<input type="submit" value="{% translate 'Save' %}" class="default" name="_save">{% endif %}
{% if show_delete_link %}
    {% url opts|admin_urlname:'delete' original.pk|admin_urlquote as delete_url %}
    <p class="deletelink-box"><a href="{% add_preserved_filters delete_url %}" class="deletelink">{% translate "Delete" %}</a></p>
{% endif %}
{% if show_cancel %}
	{% if show_save_next %}
		<input type="submit" title="{% translate 'Leave form without saving' %}" value="{% translate 'Cancel' %}" name="_cancel">
	{% else %}
		{% if cancel_url %}
			<a href="{{ cancel_url }}" class="closelink" title="{% translate 'Leave form without saving' %}">{% translate 'Cancel' %}</a>
		{% else %}
		    {% url opts|admin_urlname:'changelist' as changelist_url %}
			  <a href="{{ changelist_url }}" class="closelink" title="{% translate 'Leave form without saving' %}">{% translate 'Cancel' %}</a>
		{% endif %}
	{% endif %}
{% endif %}
{% if show_save and show_save_next %}<input type="submit" title="{% translate 'Save and go to next form in schedule' %}" value="{% translate 'Save and next' %}" name="_savenext">{% endif %}
</div>
