glucose_fieldset_tuple: tuple[str, dict[str, tuple]] = (
    "Blood Glucose Measurement",
    {
        "fields": (
            "glucose_performed",
            "glucose_fasting",
            "glucose_fasting_duration_str",
            "glucose_date",
            "glucose_value",
            "glucose_quantifier",
            "glucose_units",
        ),
    },
)
