# Generated by Django 5.1.2 on 2024-11-19 04:10

import django.core.validators
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0044_location_contact_email_location_contact_name_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicallot",
            name="manufacture_date",
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="historicalreceive",
            name="invoice_date",
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="historicalreceive",
            name="invoice_number",
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AddField(
            model_name="historicalreceive",
            name="supplier",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_pharmacy.supplier",
                verbose_name="Supplier",
            ),
        ),
        migrations.AddField(
            model_name="lot",
            name="manufacture_date",
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="receive",
            name="invoice_date",
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="receive",
            name="invoice_number",
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AddField(
            model_name="receive",
            name="supplier",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_pharmacy.supplier",
                verbose_name="Supplier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalreceiveitem",
            name="lot",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_pharmacy.lot",
                verbose_name="Batch",
            ),
        ),
        migrations.AlterField(
            model_name="location",
            name="contact_email",
            field=models.EmailField(blank=True, max_length=150, null=True),
        ),
        migrations.AlterField(
            model_name="location",
            name="contact_tel",
            field=models.CharField(
                blank=True,
                max_length=150,
                null=True,
                validators=[django.core.validators.RegexValidator("[0-9]{1,15}")],
            ),
        ),
        migrations.AlterField(
            model_name="receiveitem",
            name="lot",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_pharmacy.lot",
                verbose_name="Batch",
            ),
        ),
    ]
