# Generated by Django 5.1.2 on 2024-11-03 17:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pylabels", "0002_alter_label_options_label_created_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="label",
            name="sample_data",
            field=models.TextField(
                blank=True,
                help_text="for example, if the label_data cls is a model",
                null=True,
            ),
        ),
    ]
