# Generated by Django 5.1.2 on 2024-11-04 00:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pylabels", "0005_labelconfiguration_delete_label_and_more"),
    ]

    operations = [
        migrations.DeleteModel(
            name="Drawing",
        ),
    ]
